package sun.util.locale.provider;

import java.util.Locale;
import java.util.Set;
import java.util.spi.LocaleNameProvider;

public class LocaleNameProviderImpl extends LocaleNameProvider implements AvailableLanguageTags
{
    private final LocaleProviderAdapter.Type type;
    private final Set<String> langtags;
    
    public LocaleNameProviderImpl(LocaleProviderAdapter.Type type, Set<String> langtags) {
        this.type = type;
        this.langtags = langtags;
    }
    
    @Override
    public Locale[] getAvailableLocales() {
        return LocaleProviderAdapter.toLocaleArray(this.langtags);
    }
    
    @Override
    public boolean isSupportedLocale(Locale locale) {
        return LocaleProviderAdapter.isSupportedLocale(locale, this.type, this.langtags);
    }
    
    @Override
    public String getDisplayLanguage(String s, Locale locale) {
        return this.getDisplayString(s, locale);
    }
    
    @Override
    public String getDisplayScript(String s, Locale locale) {
        return this.getDisplayString(s, locale);
    }
    
    @Override
    public String getDisplayCountry(String s, Locale locale) {
        return this.getDisplayString(s, locale);
    }
    
    @Override
    public String getDisplayVariant(String str, Locale locale) {
        return this.getDisplayString("%%" + str, locale);
    }
    
    private String getDisplayString(String s, Locale locale) {
        if (s == null || locale == null) {
            throw new NullPointerException();
        }
        return LocaleProviderAdapter.forType(this.type).getLocaleResources(locale).getLocaleName(s);
    }
    
    @Override
    public Set<String> getAvailableLanguageTags() {
        return this.langtags;
    }
}
